<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Ativà lou plugin',
	'affichage' => 'Afichage',
	'aide_non_disponible' => 'Aquela partida de l’ajuda en ligna es pas encara dispounibla per aquela lenga.',
	'annuler_recherche' => 'Anulà la recerca',
	'auteur' => 'Autour :',
	'avis_acces_interdit' => 'Achès prouhibit.',
	'avis_article_modifie' => 'Mèfi, @nom_auteur_modif@ a travalhat soubre aquel article @date_diff@ minuta fa',
	'avis_aucun_resultat' => 'Mìnga resultat.',
	'avis_base_inaccessible' => 'Empoussible de si counetà a la basa de dounada @base@.',
	'avis_chemin_invalide_1' => 'Lou camin qu’avès chausit',
	'avis_chemin_invalide_2' => 'noun sembla vàlidou. Vourguès tournà a la pàgina prechedenta e verificà li informacioun prouvedi.',
	'avis_connexion_echec_1' => 'La counessioun a la basa de dounada a souhit.',
	'avis_connexion_echec_2' => 'Tournas à la pàgina anterioura, e verificas li informacioun qu’avès prouvedi.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Soubre touplen de servidou, devès <b>demandà</b> l’ativacioun dóu vouòstre achès a la basa de dounada denant de la poudé utilisà. Se noun vi poudès counetà, verificas qu’avès ben realisat aquela demarcha.',
	'avis_connexion_erreur_creer_base' => 'La basa de dounada a pas pouscut estre creada.',
	'avis_connexion_erreur_nom_base' => 'Lou noum de la basa de dounada pòu countenì que de letra, de chifra o de ligneta',
	'avis_connexion_ldap_echec_1' => 'La counessioun au servidou LDAP a souhit.',
	'avis_connexion_ldap_echec_2' => 'Tournas a la pàgina prechedenta, e verificas li infourmacioun qu’avès prouvedi. ',
	'avis_connexion_ldap_echec_3' => 'D’un biais alternatiéu, noun utilisas lou supouart LDAP per impourtà d’utilisaire.', # MODIF
	'avis_deplacement_rubrique' => 'Mèfi ! Aquela rùbrica counten @contient_breves@ brèva @scb@ : se la desplaçàs, vourguès ben entacà aquela casa de counfirmacioun.',
	'avis_erreur_connexion_mysql' => 'Errour de counessioun SQL',
	'avis_espace_interdit' => '<b>Espaci prouhibit</b> <div>SPIP es ja instalat.</div>',
	'avis_lecture_noms_bases_1' => 'Lou prougrama d’instalacioun a pas pouscut legì lu noum dei basa de dounada instaladi.',
	'avis_lecture_noms_bases_2' => 'Sìa minga de basa es dispounibla, sìa la founcioun que permete de listà li basa es estada desativada
		per de rasoun de segurtà (cen qu’es lou cas de plusiur aubergadour).',
	'avis_lecture_noms_bases_3' => 'En la segounda alternativa, es proubable qu’una basa que pouòrta lou vouòstre noum de counessioun sigue utilisabla :',
	'avis_non_acces_page' => 'Noun avès achès en aquela pàgina.',
	'avis_operation_echec' => 'L’ouperacioun a souhit.',
	'avis_operation_impossible' => 'Ouperacioun empoussibla',
	'avis_suppression_base' => 'MÈFI, la supressioun dei dounada es irreversibla',

	// B
	'bouton_acces_ldap' => 'Ajustà l’achès a LDAP',
	'bouton_ajouter' => 'Ajustà',
	'bouton_annuler' => 'Anulà',
	'bouton_cache_activer' => 'Reativà l’amagadou',
	'bouton_cache_desactiver' => 'Desativà tempourariamen l’amagadou',
	'bouton_demande_publication' => 'Demandà la publicacioun d’aquel article',
	'bouton_desactive_tout' => 'Desativà tout',
	'bouton_desinstaller' => 'Desinstalà',
	'bouton_effacer_tout' => 'Escassà TOUT',
	'bouton_envoyer_message' => 'Message definitiéu : mandà',
	'bouton_fermer' => 'Fermà',
	'bouton_mettre_a_jour_base' => 'Metre a jou la basa de dounada',
	'bouton_modifier' => 'Moudificà',
	'bouton_radio_afficher' => 'Afichà',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparèisse en la lista dei redatour counetat', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Mandà li anounça à l’adressa :',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandà la lista dei nouvità',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Noun aparèisse en la lista dei redatour', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Noun mandà d’anounça editouriali',
	'bouton_redirection' => 'REDIRECIOUN',
	'bouton_relancer_installation' => 'Relançà l’instalacioun',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Prouvà una recuperacioun',
	'bouton_test_proxy' => 'Prouvà lou proxy',
	'bouton_vider_cache' => 'Vuà l’amagadou',

	// C
	'cache_modifiable_webmestre' => 'Lou webmestre dóu sit pòu modificà aquèu paramètre.', # MODIF
	'calendrier_synchro' => 'S’utilisas un lougiciau d’agènda coumpatible embé <b>iCal</b>, lou poudès sincronisà emb’ai informacioun d’estou sit.',
	'config_activer_champs' => 'Ativà lu camp segoun',
	'config_choix_base_sup' => 'endicà una basa soubre aquestou servidou',
	'config_erreur_base_sup' => 'SPIP a pas achès à la lista dei basa achessibli',
	'config_info_base_sup' => 'S’avès d’autri basa de dounada à interrougà pèr SPIP, emb’au siéu servidou SQL o embé un autre, lou fourmulari aquì souta, vi permete de li declarà. Se laissas d’unu camp vuèi, lu identificant de counessioun a la basa principala seran utilisat.',
	'config_info_base_sup_disponibles' => 'Basa suplementari jà interogable :',
	'config_info_enregistree' => 'La counfiguracioun nouvela es estada registrada',
	'config_info_logos' => 'Cada elemen dóu site pòu avé un logou, e un « logou de survol »',
	'config_info_logos_utiliser' => 'Utilisà lu logou',
	'config_info_logos_utiliser_non' => 'Noun utilisà lu logou',
	'config_info_logos_utiliser_survol' => 'Utilisà lu logou de survol',
	'config_info_logos_utiliser_survol_non' => 'Noun utilisà lu logou de survol',
	'config_info_redirection' => 'En ativant aquela oupcioun, poudès creà d’article virtual, simple referença d’article publicat soubre d’autre sit o fouòra de SPIP.',
	'config_redirection' => 'Article virtual',
	'config_titre_base_sup' => 'Declaracioun d’una basa suplementari',
	'config_titre_base_sup_choix' => 'Chausissès una basa suplementari',
	'connexion_ldap' => 'Counessioun :',
	'creer_et_associer_un_auteur' => 'Creà et assoucià un autour',

	// D
	'date_mot_heures' => 'oura',

	// E
	'ecran_securite' => ' + ecran de segurtà @version@',
	'email' => 'e-mail',
	'email_2' => 'e-mail :',
	'en_savoir_plus' => 'N’en saupre de mai',
	'entree_adresse_annuaire' => 'Adressa de l’anuari',
	'entree_adresse_email' => 'La vouòstra adressa e-mail',
	'entree_adresse_email_2' => 'Adressa e-mail',
	'entree_base_donnee_1' => 'Adressa de la basa de dounada',
	'entree_base_donnee_2' => '(Souventi fès, aquela adressa courrespouònde en aquela dóu vouòstre sit, de còu courrespouònde à la mencioun « localhost », d’autre còu, es laissada vuèia coumpletamen.)',
	'entree_biographie' => 'Biougrafìa brèva, en quauque mot.',
	'entree_chemin_acces' => '<b>Entrà</b> lou camin d’achès :',
	'entree_cle_pgp' => 'La vouòstra clau PGP',
	'entree_cle_pgp_2' => 'Clau PGP',
	'entree_contenu_rubrique' => '(Countengut de la rùbrica en quauque mot.)',
	'entree_identifiants_connexion' => 'Lu vouòstre identificant de counessioun...',
	'entree_identifiants_connexion_2' => 'Identificant de counessioun',
	'entree_informations_connexion_ldap' => 'Vourguès entrà en aqueu fourmulari li informacioun de counessioun au vouòstre anuari LDAD.
Aqueli informacioun vi devon poudé estre prouvedi da l’aministratour dóu sistema, o de la taragnina.', # MODIF
	'entree_infos_perso' => 'Qu sias ?',
	'entree_infos_perso_2' => 'Qu es l’autour ?',
	'entree_interieur_rubrique' => 'Dintre la rùbrica :',
	'entree_liens_sites' => '<b>Estac ipertèst</b> (referença, sit à visità...)',
	'entree_login' => 'Lou vouòstre login',
	'entree_login_connexion_1' => 'Lou login de counessioun',
	'entree_login_connexion_2' => '(Courrespouònde de còu au vouòstre login d’accès FTP; de còu laissat vuèi)',
	'entree_mot_passe' => 'Lou vouòstre mot de passa',
	'entree_mot_passe_1' => 'Lou mot de passa de counessioun',
	'entree_mot_passe_2' => '(Courrespouònde de còu au vouòstre mot de passa per lou FTP; de còu es laissat vuèi)',
	'entree_nom_fichier' => 'Vourguès entrà lou noum dóu fichié @texte_compresse@:',
	'entree_nom_pseudo' => 'Lou vouòstre noum o lou vouòstre pseudounime',
	'entree_nom_pseudo_1' => '(Lou vouòstre noum o lou vouòstre pseudounime)',
	'entree_nom_pseudo_2' => 'Noum o pseudounime',
	'entree_nom_site' => 'Lou noum dóu vouòstre sit',
	'entree_nom_site_2' => 'Noum dóu sit de l’autour',
	'entree_nouveau_passe' => 'Mot de passa novèu',
	'entree_passe_ldap' => 'Mot de passa',
	'entree_port_annuaire' => 'Lou nùmero de pouòrt de l’anuari',
	'entree_signature' => 'Firma',
	'entree_titre_obligatoire' => '<b>Titre</b> [Oubligatori]<br />',
	'entree_url' => 'L’adressa (URL) dóu vouòstre sit',
	'entree_url_2' => 'Adressa (URL) dóu sit',
	'erreur_connect_deja_existant' => 'Un servidou esista jà embé aqueu noum',
	'erreur_email_deja_existant' => 'Aquela adressa e-mail es jà registrada.',
	'erreur_nom_connect_incorrect' => 'Aqueu noum de servidou noun es autourisat',
	'erreur_plugin_attribut_balise_manquant' => 'Atribut @attribut@ mancant en la balisa @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'La desinstalacioun dóu plugin a souhit. Mà poudès lou desativà.',
	'erreur_plugin_fichier_absent' => 'Fichié assent',
	'erreur_plugin_fichier_def_absent' => 'Fichié de definicioun assent',
	'erreur_plugin_nom_fonction_interdit' => 'Noum de founcioun prouhibit',
	'erreur_plugin_nom_manquant' => 'Noum dóu plugin mancant',
	'erreur_plugin_prefix_manquant' => 'Espaci de noumage dóu plugin noun definit',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; assent dóu fichié de definicioun',
	'erreur_plugin_version_manquant' => 'Mìnga versioun dóu plugin',

	// H
	'htaccess_a_simuler' => 'Avertimen : la counfiguracioun dóu vouòstre servidou HTTP noun ten rasoun dai fichié @htaccess@. Per poudé assegurà una bouòna segurtà, vi cóu moudificà aquela counfiguracioun soubre stou pounch, o que li coustanta @constantes@ (definissable en lou fichié mes_options.php) aiguon de repertori en defouòra de @document_root@ per valour.',
	'htaccess_inoperant' => 'htaccess inouperant',

	// I
	'ical_info1' => 'Esta pàgina presenta de metoda diferenti per restà en countat embé la vida d’estou sit.',
	'ical_info2' => 'Per avé mai d’informacioun soubre aqueli tècnica, noun esitas à counsultà <a href="@spipnet@">la doucumentacioun de SPIP</a>.',
	'ical_info_calendrier' => 'Li a doui calendari a la vouòstra dispousicioun. Lou premié es un plan dóu sit qu’anounça toui lu article publicat. Lou segount counten li anounça editoriali en mai dei vouòstre darrié message privat : v’es reservat graça a una clau persounala, que la poudès moudificà a cada moumen en renouvelant lou vouòstre mot de passa.',
	'ical_methode_http' => 'Telecargamen',
	'ical_methode_webcal' => 'Sincronisacioun (webcal://)',
	'ical_texte_prive' => 'Estou calendari, d’usage estrech personal, v’infourma de l’atività editoriala privada d’estou sit (taca e apountamen persounal, article e brèva proupausat...).',
	'ical_texte_public' => 'Estou calendari vi permete de sègre l’atività pùblica d’estou sit (article e brèva publicadi).',
	'ical_texte_rss' => 'Poudès sindicà li nouvità d’estou sit en toui lu letour de fichié en format XML/RSS (Rich Site Summary). Es finda lou format que permete à SPIP de legì li nouvità publicadi soubre d’autre sit en utilisant un format d’escambi compatible (sit sindicat).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Fichié de sindicacioun',
	'icone_accueil' => 'Acuèlh',
	'icone_activer_cookie' => 'Ativà lou cookie de courrespoundença',
	'icone_activite' => 'Atività',
	'icone_admin_plugin' => 'Gestioun dei plugin',
	'icone_administration' => 'Mantenença',
	'icone_afficher_auteurs' => 'Afichà lu autour',
	'icone_afficher_visiteurs' => 'Afichà lu visitaire',
	'icone_arret_discussion' => 'Plus participà en aquela discussioun',
	'icone_calendrier' => 'Calendari',
	'icone_configuration' => 'Counfiguracioun',
	'icone_creer_auteur' => 'Creà un nouvèl autour e l’assoucià en aquel article',
	'icone_creer_mot_cle' => 'Creà un nouvèu mot clau e lou ligà en aquel article',
	'icone_creer_rubrique_2' => 'Creà una rùbrica novèla',
	'icone_developpement' => 'Desfouloupamen',
	'icone_edition' => 'Edicioun',
	'icone_ma_langue' => 'La mieu lenga',
	'icone_mes_infos' => 'Li mieu infourmacioun',
	'icone_mes_preferences' => 'Li mieu preferença',
	'icone_modifier_article' => 'Moudificà aquel article',
	'icone_modifier_rubrique' => 'Moudificà aquela rùbrica',
	'icone_publication' => 'Publicacioun',
	'icone_relancer_signataire' => 'Relançà lou signatari',
	'icone_retour' => 'Retour',
	'icone_retour_article' => 'Retour a l’article',
	'icone_squelette' => 'Esquèletrou',
	'icone_suivi_publication' => 'Segut de la publicacioun',
	'icone_supprimer_cookie' => 'Suprimà lou cookie de courrespoundença',
	'icone_supprimer_rubrique' => 'Suprimà aquela rùbrica',
	'icone_supprimer_signature' => 'Suprimà aquela firma',
	'icone_valider_signature' => 'Validà aquela firma',
	'image_administrer_rubrique' => 'Poudès aministrà aquela rùbrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 article',
	'info_1_auteur' => '1 autour',
	'info_1_message' => '1 message',
	'info_1_mot_cle' => '1 mot clau',
	'info_1_rubrique' => '1 rùbrica',
	'info_1_visiteur' => '1 visitour',
	'info_activer_cookie' => 'Poudès ativà un <b>cookie de courrespoundença</b>; acò vi permeterà de passà facilamen dóu sit pùblicou au sit privat.',
	'info_activer_menu_developpement' => 'Afichà lou menù Desfouloupamen',
	'info_admin_etre_webmestre' => 'Mi dounà lu drech de webmèstre',
	'info_admin_je_suis_webmestre' => 'Siéu <b>webmèstre</b>',
	'info_admin_statuer_webmestre' => 'Dounà en aquel aministratour lu drech de webmèstre', # MODIF
	'info_admin_webmestre' => 'Aquel aministratour es <b>webmèstre</b>', # MODIF
	'info_administrateur' => 'Aministratour', # MODIF
	'info_administrateur_1' => 'Aministratour', # MODIF
	'info_administrateur_2' => 'dóu sit (<i>utilisas embé precaucioun</i>)',
	'info_administrateur_site_01' => 'Se sias aministratour dóu sit, vourguès', # MODIF
	'info_administrateur_site_02' => 'clicà soubre aquel estac',
	'info_administrateurs' => 'Aministratour', # MODIF
	'info_administrer_rubrique' => 'Poudès aministrà aquela rùbrica',
	'info_adresse' => 'a l’adressa:',
	'info_adresse_desinscription' => 'Adressa de desinscricioun',
	'info_adresse_url' => 'Adressa (URL) dóu sit pùblicou',
	'info_afficher_par_nb' => 'Afichà per',
	'info_aide_en_ligne' => 'Ajuda en ligna SPIP',
	'info_ajout_image' => 'Coura ajustas d’image couma doucumen jounch a un article,
		SPIP pòu creà automaticamen, per vautre, de vigneta (miniatura) dei
		image inseridi. Acò permete per isemple de creà
		automaticamen una galarìa o un pouòrtafoliò.',
	'info_ajouter_rubrique' => 'Ajustà un’autra rùbrica da aministrà:',
	'info_annonce_nouveautes' => 'Anounça dei nouvità',
	'info_article' => 'article',
	'info_article_2' => 'article',
	'info_article_a_paraitre' => 'Lu article post-datat da pareisse',
	'info_articles_02' => 'article',
	'info_articles_2' => 'Article',
	'info_articles_auteur' => 'Lu article d’aquel autour',
	'info_articles_miens' => 'Lu mieu article',
	'info_articles_tous' => 'Toui lu article',
	'info_articles_trouves' => 'Article trouvat',
	'info_attente_validation' => 'Lu vouòstre article en aspera de validacioun',
	'info_aucun_article' => 'Mìnga article',
	'info_aucun_auteur' => 'Mìnga autour',
	'info_aucun_message' => 'Minga message',
	'info_aucun_rubrique' => 'Mìnga rùbrica',
	'info_aujourdhui' => 'Ancuei :',
	'info_auteur_gere_rubriques' => 'Aquel autour gèra li rùbrica seguenti :',
	'info_auteur_gere_toutes_rubriques' => 'Aquel autour gèra <b>touti li rùbrica</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Gèri <b>touti li rùbrica</b>',
	'info_auteurs' => 'Lu autour',
	'info_auteurs_par_tri' => 'autour@partri@',
	'info_auteurs_trouves' => 'Autour trouvat',
	'info_authentification_externe' => 'Autentificacioun esterna',
	'info_avertissement' => 'Avertimen',
	'info_barre_outils' => 'embé la siéu barra d’óutis ?',
	'info_base_installee' => 'L’estrutura de la vouòstra basa de dounada es instalada.',
	'info_bio' => 'Biougrafìa',
	'info_cache_desactive' => 'L’amagadou es tempourariamen desativat.',
	'info_chapeau' => 'Capèu',
	'info_chapeau_2' => 'Capèu :',
	'info_chemin_acces_1' => 'Oupcioun : <b>camin d’achès en l’anuari</b>',
	'info_chemin_acces_2' => 'Devès ahura counfigurà lou camin d’achès ai infourmacioun en l’anuari. Aquela infourmacioun es necessari per legì lu proufiéu d’utilisaire amoulounat en l’anuari.', # MODIF
	'info_chemin_acces_annuaire' => 'Oupcioun: <b>camin d’achès en l’anuari</b>',
	'info_choix_base' => 'Tèrsa tapa :',
	'info_classement_1' => '<sup>é</sup> sus @liste@',
	'info_classement_2' => '<sup>nt</sup> sus @liste@',
	'info_code_acces' => 'Noun denembras lu vouòtre code d’achès persounal !',
	'info_config_suivi' => 'S’aquela adressa courrespouònde a una mailing-list, poudès endicà aquì souta l’adressa que lu participant au sit si pouòdon inscriéure. Aquela adressa pòu estre una URL (per isemple la pàgina d’inscricioun a la lista per web), o una adressa e-mail embé un sujet especific (per isemple : <tt>@adresse_suivi@?subject=subscribe</tt>) :',
	'info_config_suivi_explication' => 'Vi poudès abounà a la mailing-list d’estou sit. Receverès per courrié eletrounic li anounça dei article e brèva proupausat a la publicacioun.',
	'info_confirmer_passe' => 'Counfirmà aqueu mot de passa nouvèu :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Mèfi, aquelu camp soun estat moudificat da quauqun. Li vouòstri moudificacioun soubre aquelu camp noun soun estadi registradi.',
	'info_conflit_edition_differences' => 'Diferença :',
	'info_conflit_edition_version_enregistree' => 'La versioun registrada :',
	'info_conflit_edition_votre_version' => 'La vouòstra versioun :',
	'info_connexion_base' => 'Prova de counessioun a la basa',
	'info_connexion_base_donnee' => 'Counessioun a la vouòstra basa de dounada',
	'info_connexion_ldap_ok' => '<b>La counessioun LDAP a reussit.</b><p> Poudès passà a la tapa seguenta.</p>',
	'info_connexion_mysql' => 'La vouòstra counessioun SQL',
	'info_connexion_ok' => 'La counessioun a reussit.',
	'info_contact' => 'Countat',
	'info_contenu_articles' => 'Countengut dei article',
	'info_contributions' => 'Countribucioun',
	'info_creation_paragraphe' => 'Per creà de paràgrafou, laissas simplamen de ligna vuèii.',
	'info_creation_rubrique' => 'Denant de poudé escriéure d’article,<br /> devès creà au màncou una rùbrica.<br />',
	'info_creation_tables' => 'Creacioun dei taula de la basa',
	'info_creer_base' => '<b>Creà</b> una nouvela basa de dounada :',
	'info_dans_rubrique' => 'En la rùbrica:',
	'info_date_publication_anterieure' => 'Data anterioura de redacioun :',
	'info_date_referencement' => 'DATA DE REFERENÇAMEN D’AQUEU SIT :',
	'info_derniere_etape' => 'Es acabat !',
	'info_descriptif' => 'Descritiéu :',
	'info_desinstaller_plugin' => 'suprima li dounada e desativa lou plugin',
	'info_discussion_cours' => 'Discussioun en cours',
	'info_ecrire_article' => 'Denant de poudé escriéure d’article, devès au mancou creà una rùbrica.',
	'info_email_envoi' => 'Adressa e-mail d’espedissioun (oupciounau)',
	'info_email_envoi_txt' => 'Endicas aquí l’adressa da utilisà per mandà lu e-mails (en mancança, s’utiliserà l’adressa destinatàri couma adressa d’espedissioun):',
	'info_email_webmestre' => 'Adressa e-mail dóu webmèstre', # MODIF
	'info_envoi_email_automatique' => 'Espedissioun d’e-mails autoumatic',
	'info_envoyer_maintenant' => 'Mandà ahura',
	'info_etape_suivante' => 'Passà a la tapa seguenta',
	'info_etape_suivante_1' => 'Poudès passà a la tapa seguenta.',
	'info_etape_suivante_2' => 'Poudès passà a la tapa seguenta.',
	'info_exceptions_proxy' => 'Ecepcioun per lou proxy',
	'info_exportation_base' => 'Espourtacioun de la basa vers @archive@',
	'info_facilite_suivi_activite' => 'Per fin de facilità lou segut de l’atività editouriala dóu sit, SPIP vi pòu fournì per e-mail, per isemple a una mailing-list dei redatour, l’anounça dei demanda de publicacioun e de validacioun d’article.', # MODIF
	'info_fichiers_authent' => 'Fichié d’autentificacioun « .htpasswd »',
	'info_forums_abo_invites' => 'Lou vouòstre sit web counten de fòrou per lu abounat ; lu visitaire soun counvidat da si registrà soubre lou sit pùblicou.', # MODIF
	'info_gauche_admin_tech' => '<b>Aquela pàgina es basta achessible ai respounsable dóu sit.</b><p> Douna achès ai diferenti founcioun de mantenença tècnica. D’uni d’entre eli implicoun un prouchedimen d’autentificacion especific, que
 necessita d’avé un achès FTP au sit web.</p>',
	'info_gauche_auteurs' => 'Trouverès aquì toui lu autour dóu sit.
 Lou sieu estatut es endicat da la coulou de la sieu icona (aministratour : verda; redatour : jauna).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Lu autour esteriour, sensa achès au sit, soun endicat da una icona blua ; lu autour escassat da una icona grìha.',
	'info_gauche_messagerie' => 'La messagerìa vi permete d’escambià de message tra redatour, de counservà de nota de renembrança (per lou vouòstre usage persounal) o d’afichà d’anounça sus la pàgina d’acuèlh de l’espaci privat (se sias aministratour).', # MODIF
	'info_gauche_statistiques_referers' => 'Aquela pàgina presenta la lista dei <i>referit</i>, es a dire dei sit que countenon d’estac que menon drech au vouòstre sit, ma basta per ièr e ancuèi ; aquela lista es atualisada cada 24 oura.',
	'info_gauche_visiteurs_enregistres' => 'Trouverès aquì lu visitour registrat en l’espaci public dóu sit (fòrou sus abounamen).',
	'info_generation_miniatures_images' => 'Generacioun de miniatura dei image',
	'info_gerer_trad_objets' => '@objets@ : gerà lu estac de traducioun',
	'info_hebergeur_desactiver_envoi_email' => 'Lì soun d’aubergadour que desativon l’espedissioun autoumatica
		d’e-mail dai sieu servidou. En aqueu cas, li founciounalità seguenti
		de SPIP noun founciouneràn.',
	'info_hier' => 'ièr :',
	'info_identification_publique' => 'La vouòstra identità pùblica...',
	'info_image_process' => 'Vourguès seleciounà lou milhou mètodou de fabricacioun dei vigneta en clicant sus l’image courrespoundenta.',
	'info_image_process2' => 'Se minga d’image parèisse, aloura lou servidou qu’auberga lou vouòstre sit noun es estat configurat da utilisà aquelu óutis. Se vourguès utilisà aqueli founcioun, contatas lou respounsable tècnicou e demandas li estensioun « GD » o « Imagick ».',
	'info_images_auto' => 'Image carculadi automaticamen',
	'info_informations_personnelles' => 'Infourmacioun persounali',
	'info_inscription' => 'Inscricioun lou',
	'info_inscription_automatique' => 'Inscricioun autoumatica de redatour novèu', # MODIF
	'info_jeu_caractere' => 'Juèc de carater dóu sit',
	'info_jours' => 'jou',
	'info_laisser_champs_vides' => 'laissà aquelu camp vuèi)',
	'info_langues' => 'Lenga dóu sit',
	'info_ldap_ok' => 'L’autentificacioun LDAP es instalada.',
	'info_lien_hypertexte' => 'Estac ipertèst :',
	'info_liste_nouveautes_envoyee' => 'La lista dei nouvità es estada mandada',
	'info_liste_redacteurs_connectes' => 'Lista dei redatour counetat', # MODIF
	'info_login_existant' => 'Aqueu login jà esista.',
	'info_login_trop_court' => 'Login tròu court.',
	'info_login_trop_court_car_pluriel' => 'Lou login déu au màncou countenì @nb@ carater.',
	'info_logos' => 'Lu logou',
	'info_maximum' => 'massimoum :',
	'info_meme_rubrique' => 'En la mema rùbrica',
	'info_message_en_redaction' => 'Lu vouòstre message en cours de redacioun',
	'info_message_technique' => 'Message tècnicou :',
	'info_messagerie_interne' => 'Messagerìa interna',
	'info_mise_a_niveau_base' => 'Messa a nivèu de la vouòstra basa SQL',
	'info_mise_a_niveau_base_2' => '{{Mèfi!}} Avès instalat una versioun de fichié SPIP {anterioura} en aquela que si trouvava avant soubre stou sit : la vouòstra basa de dounada risca d’estre perduda e lou vouòstre sit noun founciounerà plus.<br />{{Reinstalà lu fichié de SPIP.}}',
	'info_modification_enregistree' => 'La vouòtra moudificacioun es estada registrada',
	'info_modifier_auteur' => 'Moudificà l’autour :',
	'info_modifier_rubrique' => 'Moudificà la rùbrica :',
	'info_modifier_titre' => 'Moudificà : @titre@',
	'info_mon_site_spip' => 'Lou mieu sit SPIP',
	'info_moyenne' => 'mejana :',
	'info_multi_cet_article' => 'Lenga d’aquest article :',
	'info_multi_langues_choisies' => 'Vourguès seleciounà aquì souta li lenga que soun à dispousicioun dei redatour dóu vouòstre sit.
  Li lenga ja emplegadi en lou vouòstre sit (afichadi en premié) noun si pouòdon desativà.', # MODIF
	'info_multi_objets' => '@objets@ : ativà lou menù de lenga',
	'info_multi_secteurs' => '... basta per li rùbrica da la raïs dóu sit ?',
	'info_nb_articles' => '@nb@ article',
	'info_nb_auteurs' => '@nb@ autour',
	'info_nb_messages' => '@nb@ message',
	'info_nb_mots_cles' => '@nb@ mot clau',
	'info_nb_rubriques' => '@nb@ rùbrica',
	'info_nb_visiteurs' => '@nb@ visitour',
	'info_nom' => 'Noum',
	'info_nom_destinataire' => 'Noum dóu destinatàri',
	'info_nom_pas_conforme' => 'lu tag html noun soun autourisat',
	'info_nom_site' => 'Noum dóu vouòstre site',
	'info_nombre_articles' => '@nb_articles@ article,',
	'info_nombre_rubriques' => '@nb_rubriques@ rùbrica,',
	'info_nombre_sites' => '@nb_sites@ sit,',
	'info_non_deplacer' => 'Noun desplaçà...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pòu mandà regulieramen, l’anounça dei darrieri nouvità dóu sit (article e brèva publicadi darieramen).',
	'info_non_envoi_liste_nouveautes' => 'Noun mandà la lista dei nouvità',
	'info_non_modifiable' => 'noun pòu èstre modificat',
	'info_non_suppression_mot_cle' => 'noun vouòli suprimà aqueu mot clau.',
	'info_notes' => 'Nota',
	'info_nouvel_article' => 'Nouvèl article',
	'info_nouvelle_traduction' => 'Nouvela traducioun :',
	'info_numero_article' => 'ARTICLE NÙMERO',
	'info_obligatoire_02' => '(Oubligatori)', # MODIF
	'info_option_accepter_visiteurs' => 'Achetà l’inscricioun dei visitaire dóu sit public', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Refudà l’inscricioun dei visitour', # MODIF
	'info_options_avancees' => 'OUPCIOUN AVANÇADI',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pàgina prouhibida',
	'info_par_nom' => 'da noum',
	'info_par_nombre_article' => 'da noumbre d’article',
	'info_par_statut' => 'da estatut',
	'info_par_tri' => '’(da @tri@)’',
	'info_passe_trop_court' => 'Mot de passa tròu court.',
	'info_passe_trop_court_car_pluriel' => 'Lou mot de passa dèu au màncou countenì @nb@ carater.',
	'info_passes_identiques' => 'Li doui mot de passa noun soun identic.',
	'info_plus_cinq_car' => 'mai de 5 caracter',
	'info_plus_cinq_car_2' => '(mai de 5 caracter)',
	'info_plus_trois_car' => '(mai de 3 caracter)',
	'info_popularite' => 'poupularità : @popularite@ ; visita : @visites@',
	'info_post_scriptum' => 'Post-Escrich',
	'info_post_scriptum_2' => 'Post-Escrich :',
	'info_pour' => 'per',
	'info_preview_texte' => 'Es poussible de previsualisà toui lu elemen editourial dou sit que an au màncou lou statut « proupausat », couma pura lu elemen en cours de redacioun que sian l’autour. Dèu aquela poussibilità estre duberda basta ai aministratour, a toui lu redatour, o a degun ?', # MODIF
	'info_procedez_par_etape' => 'proucedès tapa per tapa',
	'info_procedure_maj_version' => 'la proucedura de messa a jou dèu èstre lançada per adatà la basa de dounada a la nouvèla version de SPIP.',
	'info_proxy_ok' => 'Prova dóu proxy ruèisset.',
	'info_ps' => 'P.-S.',
	'info_publier' => 'publicà',
	'info_publies' => 'Lu vouòstre article publicat en ligna',
	'info_question_accepter_visiteurs' => 'Se lu esquèletrou dóu vouòstre sit prevehon lou registramen de visitour sensa achès a l’espaci privat, vourguès ativà l’oupcioun seguenta :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Achetas li inscricioun de nouvèu redatour a
 partì dau sit pùblicou ? Se l’achetàs, lu visitaire si pouran inscriéure
 da un fourmulari autoumatisat e achederan aloura a l’espaci privat per
 proupausà lu sieu article pròpi.<div class="notice">Dóu tems de la fasa d’inscricioun,
 lu utilisaire recebon un courrié eletrounic automàticou
 que li prouvedisse lu sieu code d’achès au sit privat. D’unu
 aubergadour desativon l’espedissioun d’e-mails dai sieu servidou : en aqueu cas, l’inscricioun automatica es
 empoussibla.</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travalhat sus aqueu countengut @date_diff@ minuta fa',
	'info_racine_site' => 'Raìs dóu sit',
	'info_recharger_page' => 'Vourguès recargà aquela pàgina en un moumentoun.',
	'info_recherche_auteur_zero' => 'Minga de resultat trouvat per « @cherche_auteur@ ».',
	'info_recommencer' => 'Vourguès recoumençà.',
	'info_redacteur_1' => 'Redatour',
	'info_redacteur_2' => 'qu’a achès à l’espaci privat (<i>recoumandat</i>)',
	'info_redacteurs' => 'Redatour',
	'info_redaction_en_cours' => 'EN COURS DE REDACIOUN',
	'info_redirection' => 'Redirecioun',
	'info_redirection_activee' => 'La redirecioun es ativada.',
	'info_redirection_boucle' => 'Prouvas de redirigià l’article sus èu meme',
	'info_redirection_desactivee' => 'La redirecioun es estada suprimada.',
	'info_refuses' => 'Lu vouòstre article refudat',
	'info_reglage_ldap' => 'Oupcioun: <b>Reglage de l’impourtacioun LDAP</b>',
	'info_renvoi_article' => '<b>Redirecioun.</b> Aquel article remanda a la pàgina:',
	'info_reserve_admin' => 'Basta lu aministratour pouòdon moudificà aquela adressa.', # MODIF
	'info_restreindre_rubrique' => 'Restregne la gestioun a la rùbrica :',
	'info_resultat_recherche' => 'Resultat de la recerca :',
	'info_rubriques' => 'Rùbrica',
	'info_rubriques_02' => ' rùbrica',
	'info_rubriques_trouvees' => 'Rùbrica trouvadi',
	'info_sans_titre' => 'Sensa titre',
	'info_selection_chemin_acces' => '<b>Seleciounàs</b> aquì souta lou camin d’achès en l’anuari :',
	'info_signatures' => 'firma',
	'info_site' => 'Sit',
	'info_site_2' => 'sit : ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referençat',
	'info_site_web' => 'Sit Web :',
	'info_sites' => ' sit',
	'info_sites_lies_mot' => 'Lu sit referençat ligat en aqueu mot clau',
	'info_sites_proxy' => 'Utilisà un proxy',
	'info_sites_trouves' => 'Sit trouvat',
	'info_sous_titre' => 'Souta-titre :',
	'info_statut' => 'Estatut',
	'info_statut_administrateur' => 'Aministratour', # MODIF
	'info_statut_auteur' => 'Estatut d’aquel autour :',
	'info_statut_auteur_2' => 'Siéu',
	'info_statut_auteur_a_confirmer' => 'Inscricioun da counfirmà',
	'info_statut_auteur_autre' => 'Autre statut :',
	'info_statut_redacteur' => 'Redatour',
	'info_statut_utilisateurs_1' => 'Estatut predefinit dei utilisaire impourtat', # MODIF
	'info_statut_utilisateurs_2' => 'Chausissès lou statut qu’es atribuit ai persouna presenti en l’anuari LDAP lou premié còu que si counetoun. Pourès pi moudificà aquela valour per cada autour au cas per cas.', # MODIF
	'info_suivi_activite' => 'Segut de l’atività editouriala',
	'info_surtitre' => 'Soubre-titre :',
	'info_syndication_integrale_1' => 'Lou vouòstre sit proupausa de fichié de sindicacioun (vèire « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Desirès trasmetre l’integralità dei article, o difusà un coumpèndi de quauqui centena de caracter ?',
	'info_table_prefix' => 'Poudès moudificà lou prefisse dóu noum dei taula de dounada (acò es indispensable coura si vòu instalà mai d’un sit en la mema basa de dounada). Aqueu prefisse s’ecriéu en letra minusculi, noun acentuadi, e sensa espaci.',
	'info_taille_maximale_images' => 'SPIP va prouvà la talha massimala dei image que pòu tratà (en milioun de pixel).<br /> Lu image mai grani noun seran reduchi.',
	'info_taille_maximale_vignette' => 'Talha massimala dei vigneta generadi dau sistema :',
	'info_terminer_installation' => 'Ahura poudès acabà la proucedura d’instalacioun estandarda.',
	'info_texte' => 'Tèstou',
	'info_texte_explicatif' => 'Tèstou espligatiéu',
	'info_texte_long' => '(lou tèstou es lonc : aparèisse dounca en tros destint que seràn rempegat un còu validat.)',
	'info_texte_message' => 'Tèstou dóu vouòstre message',
	'info_texte_message_02' => 'Tèst dóu message',
	'info_titre' => 'Titre :',
	'info_total' => 'toutal : ',
	'info_tous_articles_en_redaction' => 'Toui lu article en cours de redacioun',
	'info_tous_articles_presents' => 'Toui lu article publicat en aquela rùbrica',
	'info_tous_articles_refuses' => 'Toui lu article refudat',
	'info_tous_les' => 'toui lu :',
	'info_tout_site' => 'Tout lou sit',
	'info_tout_site2' => 'L’article es pas estat traduch en aquesta lenga.',
	'info_tout_site3' => 'L’article es estat traduch en aquesta lenga, mà si pourtet pi de moudificacioun a l’article de referença. La traducioun déu estre atualisada.',
	'info_tout_site4' => 'L’article es estat traduch en aquela lenga, e la traducioun es atualisada.',
	'info_tout_site5' => 'Article ouriginau.',
	'info_tout_site6' => '<b>Mèfi :</b> soulamen lu article originau s’afichon.
Li traducioun soun assouciadi a l’ouriginau,
embé una coulou qu’endica lou sieu estat :',
	'info_traductions' => 'Traducioun',
	'info_travail_colaboratif' => 'Travai coulabouratiéu sus lu article',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'una rùbrica, ',
	'info_une_rubrique_02' => '1 rùbrica',
	'info_url' => 'URL :',
	'info_url_proxy' => 'URL dóu proxy',
	'info_url_proxy_pas_conforme' => 'l’URL dóu proxy es invàlida.',
	'info_url_site_pas_conforme' => 'l’URL dóu sit noun es valide.',
	'info_url_test_proxy' => 'URL de prova',
	'info_urlref' => 'Estac ipertèst :',
	'info_utilisation_spip' => 'Ahura poudès coumençà da utilisà lou sistema de publicacioun assistat...',
	'info_visites_par_mois' => 'Afichage per mes :',
	'info_visiteur_1' => 'Visitaire',
	'info_visiteur_2' => 'dóu sit pùblicou',
	'info_visiteurs' => 'Visitaire',
	'info_visiteurs_02' => 'Visitaire dóu sit pùblicou',
	'info_webmestre_forces' => 'Lu webmèstre soun atualamen definit en <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Adressa de la basa de dounada atribuit da l’aubergadour',
	'install_connect_ok' => 'La basa nova es ben estada declarada souta lou noum de servidou @connect@.',
	'install_echec_annonce' => 'L’instalacioun va proubablamen souhì, o aboutì a un sit noun founciounal...',
	'install_extension_mbstring' => 'SPIP noun founciouna embé :',
	'install_extension_php_obligatoire' => 'SPIP esija l’estensioun PHP :',
	'install_login_base_hebergeur' => 'Login de counecioun atribuit da l’aubergadour',
	'install_nom_base_hebergeur' => 'Noum de la basa atribuit da l’aubergadour :',
	'install_pas_table' => 'Basa atualamen sensa taula',
	'install_pass_base_hebergeur' => 'Mot de passa de counecioun atribuit da l’aubergadour',
	'install_php_version' => 'PHP versioun @version@ insufisenta (minimum = @minimum@)',
	'install_select_langue' => 'Seleciounas una lenga pi clicas sus lou boutoun « seguent » per coumença la proucedura d’instalacioun.',
	'install_select_type_db' => 'Endicà lou tipe de basa de dounada :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servidou de basa de dounada atribuit da l’aubergadour',
	'install_table_prefix_hebergeur' => 'Prefisse de taula atribuit da l’aubergadour :',
	'install_tables_base' => 'Taula de la basa',
	'install_types_db_connus' => 'SPIP saup utilisà <b>MySQL</b> (lou mai repandut) e <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'Lou supouòrt de <b>PostgreSQL</b> es finda proupausat per fin d’esperimentacioun',
	'instituer_erreur_statut_a_change' => 'L’estatut es jà estat moudificat',
	'instituer_erreur_statut_non_autorise' => 'Noun poudès chausì aqueu estatut',
	'intem_redacteur' => 'redatour',
	'intitule_licence' => 'Licença',
	'item_accepter_inscriptions' => 'Achetà li inscricioun',
	'item_activer_messages_avertissement' => 'Ativà lu message d’avertimen',
	'item_administrateur_2' => 'aministratour', # MODIF
	'item_afficher_calendrier' => 'Afichà en lou calendari',
	'item_autoriser_syndication_integrale' => 'Difusì l’integralità dei article en lu fichié de sindicacioun',
	'item_choix_administrateurs' => 'lu aministratour', # MODIF
	'item_choix_generation_miniature' => 'Generà automaticamen li miniatura dei image.',
	'item_choix_non_generation_miniature' => 'Noun generà de miniatura dei image.',
	'item_choix_redacteurs' => 'lu redatour',
	'item_choix_visiteurs' => 'lu visitaire dóu sit pùblicou',
	'item_creer_fichiers_authent' => 'Creà lu fichié .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Ativà la messagerìa e l’agenda',
	'item_mots_cles_association_articles' => 'ai article',
	'item_mots_cles_association_rubriques' => 'ai rùbrica',
	'item_mots_cles_association_sites' => 'ai sit referença o sindicat',
	'item_non' => 'Noun',
	'item_non_accepter_inscriptions' => 'Noun achetà li inscricioun',
	'item_non_activer_messages_avertissement' => 'Minga message d’avertimen',
	'item_non_afficher_calendrier' => 'Noun afichà lou calendari',
	'item_non_autoriser_syndication_integrale' => 'Difondre un coumpèndi soulamen',
	'item_non_creer_fichiers_authent' => 'Noun creà aquelu fichié',
	'item_non_messagerie_agenda' => 'Desativà la messagerìa et l’agenda',
	'item_non_publier_articles' => 'Noun publicà lu article denant la data de publicacioun prevista.',
	'item_nouvel_auteur' => 'Nouvel autour',
	'item_nouvelle_rubrique' => 'Nouvela rùbrica',
	'item_oui' => 'Ahì',
	'item_publier_articles' => 'Publicà lu article, quauque sìgue la data de publicacioun',
	'item_reponse_article' => 'Respouòsta a l’article',
	'item_visiteur' => 'visitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barra d’óutis',
	'label_bando_outils_afficher' => 'Afichà lu óutis',
	'label_bando_outils_masquer' => 'Escoundre lu óutis',
	'label_choix_langue' => 'Seleciounas la vouòstra lenga',
	'label_nom_fichier_connect' => 'Endicas lou noum utilisat per aqueu servidou',
	'label_slogan_site' => 'Eslougan dóu sit',
	'label_taille_ecran' => 'Larguessa de l’ecran',
	'label_texte_et_icones_navigation' => 'Menù de navigacioun',
	'label_texte_et_icones_page' => 'Afichage en la pàgina',
	'ldap_correspondance' => 'eritage dóu camp @champ@',
	'ldap_correspondance_1' => 'Eritage dei camp LDAP',
	'ldap_correspondance_2' => 'Per cada camp SPIP seguent, endicas lou noum dóu camp LDAP courrespouòndant. Laissà vuèi per noun lou remplì, desseparà embé d’espaci o de virgula per prouvà plusiur camp LDAP.',
	'lien_ajouter_auteur' => 'Ajustà aquel autour',
	'lien_ajouter_une_rubrique' => 'Ajoutà aquela rùbrica',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOUM DÓU SIT:',
	'lien_rapide_contenu' => 'Anà au countengut',
	'lien_rapide_navigation' => 'Anà à la navigacioun',
	'lien_rapide_recherche' => 'Anà à la recerca',
	'lien_retirer_auteur' => 'Retirà l’autour',
	'lien_retirer_rubrique' => 'Retirà la rùbrica',
	'lien_retirer_tous_auteurs' => 'Retirà toui lu autour',
	'lien_retirer_toutes_rubriques' => 'Retirà touti li rùbrica toutes les rubriques',
	'lien_site' => 'sit',
	'lien_tout_decocher' => 'Destacà tout',
	'lien_tout_deplier' => 'Desplegà tout',
	'lien_tout_replier' => 'Repeglà tout',
	'lien_tout_supprimer' => 'Suprimà tout',
	'lien_trier_nom' => 'Trià da noum',
	'lien_trier_nombre_articles' => 'Trià da noumbre d’article',
	'lien_trier_statut' => 'Trià da estatut',
	'lien_voir_en_ligne' => 'VEIRE EN LIGNA:',
	'logo_article' => 'Logou de l’article',
	'logo_auteur' => 'Logou de l’autour',
	'logo_rubrique' => 'Logou de la rùbrica',
	'logo_site' => 'Logou d’estou sit',
	'logo_standard_rubrique' => 'Logou estandard dei rùbrica',
	'logo_survol' => 'Logou per lou survol',

	// M
	'menu_aide_installation_choix_base' => 'Chausida de la vouòstra basa',
	'module_fichier_langue' => 'Fichié de lenga',
	'module_raccourci' => 'Escourcha',
	'module_texte_affiche' => 'Tèstou afichat',
	'module_texte_explicatif' => 'Poudès inserà li escourcha seguenti en lu esquèletrou dóu vouòstre sit public. Si tradureràn automaticamen en li diferenti lenga per de li quali esista un fichié de lenga.',
	'module_texte_traduction' => 'Aqueu fichié de lenga « @module@ » es dispounible en :',
	'mois_non_connu' => 'noun counouissut',

	// N
	'nouvelle_version_spip' => 'La messa a jou @version@ de SPIP es dispounible',
	'nouvelle_version_spip_majeure' => 'Una nouvèla version de SPIP @version@ es dispounibla',

	// O
	'onglet_contenu' => 'Countengut',
	'onglet_declarer_une_autre_base' => 'Declarà un’autra basa',
	'onglet_discuter' => 'Discutà',
	'onglet_interactivite' => 'Interatività',
	'onglet_proprietes' => 'Prouprietà',
	'onglet_repartition_actuelle' => 'atualamen',
	'onglet_sous_rubriques' => 'Souta-rùbrica',

	// P
	'page_pas_proxy' => 'Aquela pàgina noun déu passà per lou proxy',
	'pas_de_proxy_pour' => 'Poudès endicas li machina o lu doumani doun aqueu proxy noun déu s’aplicà (per isemple: @exemple@)',
	'phpinfo' => 'Counfiguracioun PHP',
	'plugin_charge_paquet' => 'Cargamen dóu paquet @name@',
	'plugin_charger' => 'Telecargà',
	'plugin_erreur_charger' => 'errour : empoussible de cargà @zip@',
	'plugin_erreur_droit1' => 'Lou repertori <code>@dest@</code> noun es achessible en escritura.',
	'plugin_erreur_droit2' => 'Vourguès verificà lu drech sus aqueu repertori (e lou creà se besoun), o instalà lu fichié per FTP.',
	'plugin_erreur_zip' => 'souhit pclzip : errour @status@',
	'plugin_etat_developpement' => 'en desfouloupamen',
	'plugin_etat_experimental' => 'esperimental',
	'plugin_etat_stable' => 'estable',
	'plugin_etat_test' => 'en prova',
	'plugin_impossible_activer' => 'Empoussible d’ativà lou plugin @plugin@',
	'plugin_info_automatique1' => 'Se souetas autourisà l’instalacioun autoumatic dei plugin, vourguès :',
	'plugin_info_automatique1_lib' => 'Se souetas autourisà l’instalacioun autoumatic d’aquela biblioutéca, vourguès :',
	'plugin_info_automatique2' => 'creà un repertori <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verifica que lou servidou es autourisat a escrieure en aqueu repertori.',
	'plugin_info_automatique_creer' => 'a creà a la raìs dau sit.',
	'plugin_info_automatique_exemples' => 'isemple :',
	'plugin_info_automatique_ftp' => 'Poudès instalà de plugin, per FTP, en lou repertori <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'D’uni plugin necessiton de poudé telecargà dei fichié en lou repertori <code>lib/</code>, a creà se besoun a la raìs dau sit.',
	'plugin_info_automatique_liste' => 'Lu vouòtre lista de plugin :',
	'plugin_info_automatique_liste_officielle' => 'lu plugin óuficial',
	'plugin_info_automatique_liste_update' => 'Metre a jou li lista',
	'plugin_info_automatique_ou' => 'o...',
	'plugin_info_automatique_select' => 'Seleciounas aquì souta un plugin : SPIP lou telecarguera e l’instalera en lou repertori <code>@rep@</code> ; se aqueu plugin ja esistà, serà mes a jou.',
	'plugin_info_credit' => 'Credit',
	'plugin_info_erreur_xml' => 'La declaracioun d’aqueu plugin es ?! incorrecte ?!',
	'plugin_info_install_ok' => 'Instalacioun rueisseda',
	'plugin_info_necessite' => 'Necessita :',
	'plugin_info_non_compatible_spip' => 'Aqueu plugin noun es coumpatible embé aquela versioun de SPIP',
	'plugin_info_plugins_dist_1' => 'Lu plugin aquì souta soun cargat e ativat en lou repertori @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Noun soun deativable.',
	'plugin_info_telecharger' => 'a telecargà sus @url@ e a instalà en @rep@',
	'plugin_info_upgrade_ok' => 'Messa a jou rueisseda',
	'plugin_librairies_installees' => 'Biblioutéca instaladi',
	'plugin_necessite_extension_php' => 'Necessita l’estensioun PHP @plugin@ en versioun @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Necessita l’estencioun PHP @plugin@',
	'plugin_necessite_lib' => 'Aqueu plugin necessita la biblioutéca @lib@',
	'plugin_necessite_php' => 'Necessita @plugin@ en versioun @version@.',
	'plugin_necessite_plugin' => 'Necessita lou plugin @plugin@ en versioun @version@.',
	'plugin_necessite_plugin_sans_version' => 'Necessita lou plugin @plugin@',
	'plugin_necessite_spip' => 'Necessita SPIP en versioun @version@ minimum.',
	'plugin_source' => 'source : ',
	'plugin_titre_automatique' => 'Instalacioun autoumatic',
	'plugin_titre_automatique_ajouter' => 'Ajustà dei plugin',
	'plugin_titre_installation' => 'Instalacioun dóu plugin @plugin@',
	'plugin_titre_modifier' => 'Lu miéu plugin',
	'plugin_utilise_extension_php' => 'Utilisa l’estencioun PHP @plugin@ en versioun @version@.', # MODIF
	'plugin_utilise_php' => 'Utilisa @plugin@ en versioun @version@.', # MODIF
	'plugin_utilise_plugin' => 'Utilisa lou plugin @plugin@ en versioun @version@.', # MODIF
	'plugin_zip_active' => 'Countinuas per l’ativà',
	'plugin_zip_adresse' => 'endicas aquì souta l’adressa d’un fichié zip de plugin a telecargà, o ben l’adressa d’una lista de plugin.',
	'plugin_zip_adresse_champ' => 'Adressa dóu plugin o de la lista ',
	'plugin_zip_content' => 'Counten lu fichié seguent (@taille@),<br />lest a instalà en lou repertori <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Lou fichié @zip@ es estat deserat e instalat.',
	'plugin_zip_installe_rep_finie' => 'Lou fichié @zip@ estat deserat e instalat en lou repertori @rep@',
	'plugin_zip_installer' => 'Poudès ahura l’instalà.',
	'plugin_zip_telecharge' => 'Lou fichié  @zip@ es estat telecargat',
	'plugins_actif_aucun' => 'Minga plugin ativat.',
	'plugins_actif_un' => 'Un plugin ativat.',
	'plugins_actifs' => '@count@ plugin ativat.',
	'plugins_actifs_liste' => 'Atiéu',
	'plugins_compte' => '@count@ plugin',
	'plugins_disponible_un' => 'Un plugin dispounible.',
	'plugins_disponibles' => '@count@ plugin dispounible.',
	'plugins_erreur' => 'Errour en lu plugin : @plugins@',
	'plugins_liste' => 'Lista dei plugin',
	'plugins_liste_dist' => 'Plugin ferouiat',
	'plugins_recents' => 'Plugin réchent.',
	'plugins_tous_liste' => 'Toui',
	'plugins_vue_hierarchie' => 'Gerarquìa',
	'plugins_vue_liste' => 'Lista',
	'protocole_ldap' => 'Versioun dóu proutoucole :',

	// Q
	'queue_executer_maintenant' => 'Esecutà ahura',
	'queue_info_purger' => 'Poudès supprimà toui lu travai en aspera et reinicialisà la lista emb’ai travai periòdicou', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ travai en aspera', # MODIF
	'queue_next_job_in_nb_sec' => 'Travai que ven en @nb@ s', # MODIF
	'queue_no_job_in_queue' => 'Minga travai en aspera', # MODIF
	'queue_one_job_in_queue' => '1 travai en aspera', # MODIF
	'queue_purger_queue' => 'Reinitialisà la lista dei travai', # MODIF
	'queue_titre' => 'Lista dei travai', # MODIF

	// R
	'repertoire_plugins' => 'Repertori :',
	'required' => ' (oubligatori)', # MODIF

	// S
	'sans_heure' => 'sensa oura',
	'statut_admin_restreint' => 'admin limitat',
	'statut_webmestre' => 'webmestre',

	// T
	'tache_cron_asap' => 'Tàcha CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tàcha CRON @function@ (touti li @nb@ s)',
	'taille_cache_image' => 'Lu image que SPIP a carculat automaticamen (vigneta dei doucumen, titre presentat en forma gràfica, founcioun matemàtiqui en forma TeX...) oucupon un toutal de @taille@ en lou repertori @dir@.',
	'taille_cache_moins_de' => 'La talha de l’amagadou es màncou de @octets@.',
	'taille_cache_octets' => 'Ahura la talha de l’amagador es cìrca de @octets@.',
	'taille_cache_vide' => 'L’amagadou es vuèi.',
	'taille_repertoire_cache' => 'Talha dóu repertori amagadou',
	'text_article_propose_publication' => 'Article proupausat per la publicacioun.',
	'texte_acces_ldap_anonyme_1' => 'Certen servidou LDAP achèton minga d’achès anounime. En aqueu cas, cau spechificà un identificant d’achès inicial per poudé pi recercà d’informacion en l’annuari. Lu camp seguent si pouràn laissà vuèi en la majour part dei cas.',
	'texte_admin_effacer_01' => 'Aquela coumanda escafa <i>tout</i> lou countengut de la basa de dounada,
 embé <i>toui</i> lu achès redatour e aministratour. Coura l’aurès eseguit, deurès
reinstalà SPIP per recreà una basa nouvèla couma pura un premié achès aministratour.', # MODIF
	'texte_adresse_annuaire_1' => '(Se lou vouòstre annuari es instalat soubre la mema màquina qu’estou sit web, si trata proubablamen de « localhost ».)',
	'texte_ajout_auteur' => 'L’autour seguent es estat ajustat a l’article :',
	'texte_annuaire_ldap_1' => 'S’avès achès a un annuari (LDAP), lou poudès utilisà per ', # MODIF
	'texte_article_statut' => 'Aquel article :',
	'texte_article_virtuel' => 'Article virtual',
	'texte_article_virtuel_reference' => '<b>Article virtual :</b> article referençat en lou vouòstre sit SPIP, mà redirigit vers una autra URL. Per suprimà la redirecioun, escassas l’URL aquì soubre.',
	'texte_aucun_resultat_auteur' => 'Minga resultat per « @cherche_auteur@ »',
	'texte_auteur_messagerie' => 'Estou sit vi pòu endicà en permanença la lista dei redatour counetat, cen que vi permete d’escambià de message en diret. Poudès dechìdre de noun aparèisse en aquela lista (siès « invisible/a » dei autre utilisaire).', # MODIF
	'texte_auteurs' => 'LU AUTOUR',
	'texte_choix_base_1' => 'Chausissès la vouòstra basa:',
	'texte_choix_base_2' => 'Lou servidou SQL counten mai d’una basa de dounada.',
	'texte_choix_base_3' => '<b>Chausissès</b> aquì souta aquela que lou vouòstre aubergadour v’a atribuit :',
	'texte_choix_table_prefix' => 'Prefis dei taula :',
	'texte_compte_element' => '@count@ elemen',
	'texte_compte_elements' => '@count@ elemen',
	'texte_conflit_edition_correction' => 'Vourguès countroulà aquì souta li diferença tra li doui versioun dóu tèstou ; poudès finda coupià li vouòstri moudificacioun, pi recoumençà.',
	'texte_connexion_mysql' => 'Counsultas li infourmacioun que lou vouòstre aubergadour fournisse : li devès troubà lou servidou de basa de dounada que proupausa e lu identificant persounal per vi counetà.',
	'texte_contenu_article' => '(Countengut de l’article en quauque mot.)',
	'texte_contenu_articles' => 'Segoun la maqueta que lou vouòstre sit a adoutada, poudès dechidre
		que d’unu elemen dei article noun soun utilisat.
		Utilisas la lista aquì souta per endicà quau elemen soun dispounible.',
	'texte_crash_base' => 'Se la vouòstra basa de dounada s’es
 			encalada, poudès prouvà una reparacioun
 			autoumatica.',
	'texte_creer_rubrique' => 'Denant de poudé escrieure d’articles<br/>, devès creà una rùbrica.',
	'texte_date_creation_article' => 'DATA DE CREACIOUN DE L’ARTICLE:', # on ajoute le ":"
	'texte_date_creation_objet' => 'Data de créacioun :', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Data de redacioun anterioura :',
	'texte_date_publication_anterieure_nonaffichee' => 'Noun faire aparèisse de data de redacioun anterioura.',
	'texte_date_publication_article' => 'DATA DE PUBLICACIOUN EN LIGNA:',
	'texte_date_publication_objet' => 'Data de publicacioun en ligna :',
	'texte_definir_comme_traduction_rubrique' => 'Aquela rùbrica es una traducioun de la rùbrica nùmero :',
	'texte_descriptif_rapide' => 'Descritiéu rapide',
	'texte_effacer_base' => 'Escassà la basa de dounada SPIP',
	'texte_effacer_statistiques' => 'Escassà li estatìstica',
	'texte_en_cours_validation' => 'Lu countengut aquì souta asperoun d’estre validat.',
	'texte_enrichir_mise_a_jour' => 'Poudès enriquì la coumpaginacioun dóu vouòstre tèstou en utilisant d’« escourcha tipougràfica »',
	'texte_fichier_authent' => '<b>Déu SPIP creà de fichié especial
<tt>.htpasswd</tt> e <tt>.htpasswd-admin</tt> en lou repertori @dossier@ ?</b>
<p>Aquelu fichié vi pouòdon servì per restrègne l’achès ai autour e aministratour en d’autre luèc dóu vouòstre sit (prougrama estèrnou d’estatìstica, per isemple).</p>
<p>Se noun vi sièrve, poudès laissà aquesla oupcioun a la sieu valour predefinida (minga de creacioun de fichié).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Ahura lou sistèma vi va creà un achès persounalisat au sit.',
	'texte_informations_personnelles_2' => '(Nota : es una reinstalacioun, se lou vouòstre achès marcha encara, poudès',
	'texte_introductif_article' => '(Test introdutiu de l’article.)',
	'texte_jeu_caractere' => 'Es counsilhat d’emplegà, sus lou vouòstre sit, l’alfabet universal (<tt>utf-8</tt>) : permete d’afichà de tèstou en touti li lenga sensa proublema de coumpatibilità emb’ai navigatour mouderne.',
	'texte_jeu_caractere_3' => 'Lou vouòstre sit es atualamen instalat dau juèc de carater :',
	'texte_jeu_caractere_4' => 'En cas qu’acò noun courrespouònde a la realità dei vouòstri dounada (après, per isemple, una restouracioun de basa de dounada), o <em>que coumencas estou sit</em> e desiras chausì un autre juèc de caracter, endicas-lou aicí : ',
	'texte_login_ldap_1' => '(Laissà vuèi per un achès anounime, o intrà lou camin coumplet, per isemple «<tt>uid=fabre, ou=users, dc=lou-mieu-doumìni, dc=com</tt>».)',
	'texte_login_precaution' => 'Mèfi ! Acò es lou login emb’au qual sias ahura counetat. 
 Utilisas aqueu fourmulari embé precaucioun...',
	'texte_messagerie_agenda' => 'Una messagerìa permete ai redatour dóu sit de coumunicà diretamen tra elu en l’espaci privat dóu sit. Es assouciada a un agènda.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Venès de metre a jou lu fichié SPIP.
 	Ahura cau metre a nivèu la basa de dounada
 	dóu sit.',
	'texte_modifier_article' => 'Moudificà l’article :',
	'texte_multilinguisme' => 'Se vourguès gerà d’ouget en mai d’una lenga, embé una navigacioun complessa, poudès ajustà un menù de selecioun de lenga sus aquelu ouget, en founcioun de l’ourganisacioun dóu vouòstre sit.',
	'texte_multilinguisme_trad' => 'Poudès finda ativà un sistema de gestioun dei estac tra li diferenti traducioun sus certen ouget.',
	'texte_non_compresse' => '<i>noun coumprimat</i> (lou vouòstre servidou noun supouòrta aquela founciounalità)',
	'texte_nouvelle_version_spip_1' => 'Avès instalat una nouvèla versioun de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquela versioun nouvèla demanda una messa a jou mai coumpleta qu’a l’acoustumada. Se siès webmèstre dóu sit, vourguès escassà lou fichié @connect@ e repilhà l’instalacioun per fin d’atualisà lu vouòstre parametre de counessioun a la basa de dounada.<p> (NB: s’avès denembrat lu vouòstre parametre de counessioun, regarjas lou fichié @connect@ denant de lou suprimà...)</p>',
	'texte_operation_echec' => 'Tournas a la pàgina prechedenta, chausissès una autra basa o creas nen una nouvèla. Verificas li infourmacioun que lou vouòstre aubergadour v’a fournidi.',
	'texte_plus_trois_car' => 'mai de 3 caracter',
	'texte_plusieurs_articles' => 'Plusiur autour troubat per « @cherche_auteur@ »:',
	'texte_port_annuaire' => '(La valour predefinida counven generalamen.)',
	'texte_presente_plugin' => 'Aquela pàgina lista lu plugin dispounible sus lou sit. Poudès ativà lu plugin necessari en entacant la casa courrespoundenta.',
	'texte_proposer_publication' => 'Quoura lou vouòstre article sera acabat,<br /> pourès proupausà la siéu publicacioun.',
	'texte_proxy' => 'De còu que lì a (intranet, rets protegidi...), lu sit distant (doucumentacioun de SPIP, sit sindicat, eca.) soun achessible qu’a travès un <i>proxy</i>. En aqueu cas, endiquès aquì souta la siéu adressa coum’acò @proxy_en_cours@. En general, laisserès aquèla casa vuèia',
	'texte_publication_articles_post_dates' => 'Couma SPIP si deu coumpourtà emb’ai article que la sieu
		data de publicacioun es fissada a una 
		escadença futura ?',
	'texte_rappel_selection_champs' => '[Noun denembras de seleciounà courretamen aqueu camp.]',
	'texte_recalcul_page' => 'Se voulès
recarculà soulamen una pàgina, passas pulèu per l’espaci public et utilisas lou boutoun « recarculà ».',
	'texte_recuperer_base' => 'Reparà la basa de dounada',
	'texte_reference_mais_redirige' => 'article referençat en lou vouòstre sit SPIP, ma redirigiat vèrs un’autra URL.',
	'texte_requetes_echouent' => '<b>Quoura certeni requesta SQL souhon
  sistematicamen e sensa rasoun aparenta, si pòu
  qu’acò vengue de la basa de dounada.</b><p>
  Lou vouòstre servidou SQL a la facultà de reparà li sieu
  taula quoura li soun estadi degalhadi per achident. Aquì poudès prouvà aquela reparacioun ; se 
  noun marche, counservas una còpia de l’afichage, que counten bessai
 d’indìci de cen que noun marcha...</p><p>
  Se lou proublema persiste, countactas lou vouòstre
  aubergadour.</p>',
	'texte_selection_langue_principale' => 'Poudès seleciounà aquì souta la « lenga principala » dóu sit. Aquela chausida noun v’oubligia - gauch proun que noun - da escriéure lu vouòstre article en la lenga seleciounada, ma permete de determinà :
 <ul><li> lou fourmat predefinit dei data soubre lou sit pùblicou ;</li>
 <li> la natura dóu moutour tipougràficou que SPIP déu utilisà per lou rendut dei tèstou;</li>
 <li> la lenga utilisada en lu fourmulari dóu sit pùblicou;</li>
 <li> la lenga presentada couma predefinida en l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Souta-titre',
	'texte_statistiques_visites' => '(barra founçadi :  dimènegue / curva founçadi : evoulucioun de la mejàna)',
	'texte_statut_attente_validation' => 'en aspèra de validacioun',
	'texte_statut_publies' => 'publicat en ligna',
	'texte_statut_refuses' => 'refudat',
	'texte_suppression_fichiers' => 'Utilisas aquela coumanda per fin de suprimà toui lu fichié que si trouvon
en l’amagadou SPIP. Acò permete per isemple de fourçà un nouvèu carcul de touti li pàgina
s’avès fach dei moudificacioun empourtanti de grafisme o d’estrutura dóu sit.',
	'texte_sur_titre' => 'Soubre-titre',
	'texte_table_ok' => ': aquela taula va ben.',
	'texte_tentative_recuperation' => 'Tentativa de reparacioun',
	'texte_tenter_reparation' => 'Prouvà de reparà la basa de dounada',
	'texte_test_proxy' => 'Per prouvà aqueu proxy, endicas aquì l’adressa d’un sit web
    que lou vourias prouvà.',
	'texte_titre_02' => 'Titre :',
	'texte_titre_obligatoire' => '<b>Titre</b> [Oubligatori]',
	'texte_travail_article' => '@nom_auteur_modif@ a trabalhat sus aquel article @date_diff@ minuta fa',
	'texte_travail_collaboratif' => 'Coura es frequent que mai d’un redatour 
  travalhe sus lou meme article, lou sistema
  pòu afichà lu article darieramen « dubèrt »
  per fin d’evità li moudificacioun fachi ensen.
  Aquela oupcioun es desativada de maniera predefinida
  per fin d’evità d’afichà de message d’avertimen
  intempestiéu.', # MODIF
	'texte_vide' => 'vuèi',
	'texte_vider_cache' => 'Vuà l’amagadou',
	'titre_admin_tech' => 'Mantenença tècnica',
	'titre_ajouter_un_auteur' => 'Ajustà un autour',
	'titre_ajouter_un_mot' => 'Ajustà un mot-clau',
	'titre_cadre_afficher_article' => 'Afichà lu article',
	'titre_cadre_afficher_traductions' => 'Afichà l’estat dei traducioun dai lenga segenti :',
	'titre_cadre_ajouter_auteur' => 'AJUSTÀ UN AUTOUR :',
	'titre_cadre_interieur_rubrique' => 'En la rùbrica',
	'titre_cadre_numero_auteur' => 'AUTOUR NÙMERO',
	'titre_cadre_numero_objet' => '@objet@ NÙMERO :',
	'titre_cadre_signature_obligatoire' => '<b>Firma</b> [Oubligatori]<br />',
	'titre_config_contenu_notifications' => 'Noutificatioun',
	'titre_config_contenu_prive' => 'En l’espaci privat',
	'titre_config_contenu_public' => 'Soubre lou sit pùblicou',
	'titre_config_fonctions' => 'Counfiguracioun dóu sit',
	'titre_config_langage' => 'Counfigurà la lenga',
	'titre_configuration' => 'Counfiguracioun dóu sit',
	'titre_configurer_preferences' => 'Counfigurà li vouòstri preferença',
	'titre_configurer_preferences_menus' => 'Counfigurà li vouòstri preferença de menù',
	'titre_conflit_edition' => 'Counflit dóu tems de l’edicioun',
	'titre_connexion_ldap' => 'Oupcioun : <b>La vouòstra counessioun LDAP</b>',
	'titre_groupe_mots' => 'GROUP DE MOT :',
	'titre_identite_site' => 'Identità dóu sit',
	'titre_langue_article' => 'Lenga de l’article',
	'titre_langue_rubrique' => 'Lenga de la rùbrica',
	'titre_langue_trad_article' => 'LENGA E TRADUCIOUN DE L’ARTICLE',
	'titre_les_articles' => 'LU ARTICLE',
	'titre_messagerie_agenda' => 'Messagerìa e agenda',
	'titre_naviguer_dans_le_site' => 'Navigà en lou sit...',
	'titre_nouvelle_rubrique' => 'Nouvèla rùbrica',
	'titre_numero_rubrique' => 'RÙBRICA NÙMERO :',
	'titre_page_articles_edit' => 'Moudificà : @titre@',
	'titre_page_articles_page' => 'Lu article',
	'titre_page_articles_tous' => 'Tout lou sit',
	'titre_page_calendrier' => 'Calendari @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Counfiguracioun dóu sit',
	'titre_page_delete_all' => 'supressioun toutala e irreversibla',
	'titre_page_recherche' => 'Resultat de la recerca @recherche@',
	'titre_page_statistiques_referers' => 'Estatistica (estac intrant)',
	'titre_page_upgrade' => 'Messa a nivèu de SPIP',
	'titre_preference_menus_favoris' => 'Menù favourit',
	'titre_publication_articles_post_dates' => 'Publicacioun dei article post-datat',
	'titre_reparation' => 'Reparacioun',
	'titre_suivi_petition' => 'Segut dei peticioun',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Touti li versioun d’aquel article :',
	'trad_delier' => 'Pus legà aquel article ai traducioun sieui',
	'trad_lier' => 'Aquel article es una traducioun de l’article nùmero :',
	'trad_new' => 'Escrieure una nouvèla traducioun',

	// U
	'utf8_convert_erreur_orig' => 'Errour : lou juèc de caractèr @charset@ es pas supourtat.',

	// V
	'version' => 'Versioun:',
];
